@@ -53,21 +53,24 @@ GET_VIP_LOAN_ORDER_DETAIL= '/api/v5/account/vip-loan-order-detail'
 SET_RISK_OFFSET_TYPE = '/api/v5/account/set-riskOffset-type'
 SET_AUTO_LOAN = '/api/v5/account/set-auto-loan'
 ACTIVSTE_OPTION = '/api/v5/account/activate-option'
+POSITION_BUILDER = '/api/v5/account/position-builder'
+GET_INSTRUMENTS = '/api/v5/account/instruments'
 
 # funding-complete-testcomplete
+NON_TRADABLE_ASSETS = '/api/v5/asset/non-tradable-assets'
 DEPOSIT_ADDRESS = '/api/v5/asset/deposit-address'
 GET_BALANCES = '/api/v5/asset/balances'
 FUNDS_TRANSFER = '/api/v5/asset/transfer'
 TRANSFER_STATE = '/api/v5/asset/transfer-state'
 WITHDRAWAL_COIN = '/api/v5/asset/withdrawal'
-DEPOSIT_HISTORIY = '/api/v5/asset/deposit-history'
+DEPOSIT_HISTORY = '/api/v5/asset/deposit-history'
 CURRENCY_INFO = '/api/v5/asset/currencies'
 PURCHASE_REDEMPT = '/api/v5/asset/purchase_redempt'
 BILLS_INFO = '/api/v5/asset/bills'
 DEPOSIT_LIGHTNING = '/api/v5/asset/deposit-lightning'
 WITHDRAWAL_LIGHTNING = '/api/v5/asset/withdrawal-lightning'
 CANCEL_WITHDRAWAL = '/api/v5/asset/cancel-withdrawal' #need add
-WITHDRAWAL_HISTORIY = '/api/v5/asset/withdrawal-history'
+WITHDRAWAL_HISTORY = '/api/v5/asset/withdrawal-history'
 CONVERT_DUST_ASSETS = '/api/v5/asset/convert-dust-assets' #need add
 ASSET_VALUATION = '/api/v5/asset/asset-valuation' #need add
 SET_LENDING_RATE = '/api/v5/asset/set-lending-rate'
@@ -138,8 +141,8 @@ TAKER_FLOW = '/api/v5/rubik/stat/option/taker-block-volume'
 # TRADE-Complete
 PLACR_ORDER = '/api/v5/trade/order'
 BATCH_ORDERS = '/api/v5/trade/batch-orders'
-CANAEL_ORDER = '/api/v5/trade/cancel-order'
-CANAEL_BATCH_ORDERS = '/api/v5/trade/cancel-batch-orders'
+CANCEL_ORDER = '/api/v5/trade/cancel-order'
+CANCEL_BATCH_ORDERS = '/api/v5/trade/cancel-batch-orders'
 AMEND_ORDER = '/api/v5/trade/amend-order'
 AMEND_BATCH_ORDER = '/api/v5/trade/amend-batch-orders'
 CLOSE_POSITION = '/api/v5/trade/close-position'
@@ -152,7 +155,7 @@ ORDERS_FILLS_HISTORY = '/api/v5/trade/fills-history'
 PLACE_ALGO_ORDER = '/api/v5/trade/order-algo'
 CANCEL_ALGOS = '/api/v5/trade/cancel-algos'
 Cancel_Advance_Algos = '/api/v5/trade/cancel-advance-algos'
-ORDERS_ALGO_OENDING = '/api/v5/trade/orders-algo-pending'
+ORDERS_ALGO_PENDING = '/api/v5/trade/orders-algo-pending'
 ORDERS_ALGO_HISTORY = '/api/v5/trade/orders-algo-history'
 GET_ALGO_ORDER_DETAILS = '/api/v5/trade/order-algo'
 AMEND_ALGO_ORDER = '/api/v5/trade/amend-algos'
@@ -177,7 +180,6 @@ GET_ASSET_SUBACCOUNT_BALANCE = '/api/v5/asset/subaccount/balances' #need to add
 GET_THE_USER_AFFILIATE_REBATE = '/api/v5/users/partner/if-rebate'
 SET_SUB_ACCOUNTS_VIP_LOAN = '/api/v5/account/subaccount/set-loan-allocation'
 GET_SUB_ACCOUNT_BORROW_INTEREST_AND_LIMIT = '/api/v5/account/subaccount/interest-limits'
-GET_HISTORY_OF_MANAGED_SUB_ACCOUNT_TRANSFER = '/api/v5/asset/subaccount/managed-subaccount-bills'
 
 # Broker-all need to implmented-completed
 BROKER_INFO = '/api/v5/broker/nd/info'
@@ -197,7 +199,6 @@ GET_REBATE_PER_ORDERS = '/api/v5/broker/nd/rebate-per-orders'
 REBATE_PER_ORDERS = '/api/v5/broker/nd/rebate-per-orders'
 MODIFY_SUBACCOUNT_DEPOSIT_ADDRESS = '/api/v5/asset/broker/nd/modify-subaccount-deposit-address'
 GET_SUBACCOUNT_DEPOSIT='/api/v5/asset/broker/nd/subaccount-deposit-address'
-SET_ND_SUB_ACCOUNT_ASSET_IN_DEMO_TRADING='/api/v5/broker/nd/set-subaccount-assets'
 
 # Convert-Complete
 GET_CURRENCIES = '/api/v5/asset/convert/currencies'
@@ -279,10 +280,10 @@ GET_PROFIT_SHARING_DETAILS = '/api/v5/copytrading/profit-sharing-details'
 GET_TOTAL_PROFIT_SHARING = '/api/v5/copytrading/total-profit-sharing'
 GET_UNREALIZED_PROFIT_SHARING_DETAILS = '/api/v5/copytrading/unrealized-profit-sharing-details'
 
-# Spread Trading
+# Spread Trading˚
 SPREAD_PLACE_ORDER= '/api/v5/sprd/order'
-SPREAD_CANAEL_ORDER = '/api/v5/sprd/cancel-order'
-SPREAD_CANAEL_ALL_ORDERS = '/api/v5/sprd/mass-cancel'
+SPREAD_CANCEL_ORDER = '/api/v5/sprd/cancel-order'
+SPREAD_CANCEL_ALL_ORDERS = '/api/v5/sprd/mass-cancel'
 SPREAD_GET_ORDER_DETAILS = '/api/v5/sprd/order'
 SPREAD_GET_ACTIVE_ORDERS = '/api/v5/sprd/orders-pending'
 SPREAD_GET_ORDERS = '/api/v5/sprd/orders-history'
@@ -291,5 +292,3 @@ SPREAD_GET_SPREADS = '/api/v5/sprd/spreads'
 SPREAD_GET_ORDER_BOOK = '/api/v5/sprd/books'
 SPREAD_GET_TICKER = '/api/v5/sprd/ticker'
 SPREAD_GET_PUBLIC_TRADES = '/api/v5/sprd/public-trades'
-
-
